@@ -483,7 +483,7 @@ void EDA_BASE_FRAME::ReCreateMenuBar()
      * ensure that they do not occur within the same event handling call stack.
      */
 
-    CallAfter( [&]()
+    CallAfter( [this]()
                {
                    if( !m_isClosing )
                        doReCreateMenuBar();
@@ -1202,6 +1202,7 @@ void EDA_BASE_FRAME::ShowPreferences( wxString aStartPage, wxString aStartParent
             book->AddPage( new wxPanel( book ), _( "Gerber Viewer" ) );
             book->AddLazySubPage( LAZY_CTOR( PANEL_GBR_DISPLAY_OPTIONS ), _( "Display Options" ) );
             book->AddLazySubPage( LAZY_CTOR( PANEL_GBR_COLORS ), _( "Colors" ) );
+            book->AddLazySubPage( LAZY_CTOR( PANEL_GBR_GRIDS ), _( "Grids" ) );
             book->AddLazySubPage( LAZY_CTOR( PANEL_GBR_EXCELLON_OPTIONS ), _( "Excellon Options" ) );
         }
         catch( ... )
