@@ -362,7 +362,6 @@ bool TOOL_MANAGER::doRunAction( const TOOL_ACTION& aAction, bool aNow, const std
 
             while( synchronousControl == STS_RUNNING )
             {
-                wxMilliSleep( 50 );
                 wxYield();
             }
 
@@ -705,7 +704,7 @@ TOOL_EVENT* TOOL_MANAGER::ScheduleWait( TOOL_BASE* aTool, const TOOL_EVENT_LIST&
 {
     TOOL_STATE* st = m_toolState[aTool];
 
-    wxASSERT( !st->pendingWait ); // everything collapses on two KiYield() in a row
+    wxCHECK( !st->pendingWait, nullptr ); // everything collapses on two KiYield() in a row
 
     // indicate to the manager that we are going to sleep and we shall be
     // woken up when an event matching aConditions arrive
@@ -942,8 +941,14 @@ void TOOL_MANAGER::DispatchContextMenu( const TOOL_EVENT& aEvent )
         if( wxWindow* frame = dynamic_cast<wxWindow*>( m_frame ) )
             frame->PopupMenu( menu.get() );
 
-        // If a menu is canceled then notify tool
-        if( menu->GetSelected() < 0 )
+        // Warp the cursor if a menu item was selected
+        if( menu->GetSelected() >= 0 )
+        {
+            if( m_viewControls && m_warpMouseAfterContextMenu )
+                m_viewControls->WarpMouseCursor( m_menuCursor, true, false );
+        }
+        // Otherwise notify the tool of a cancelled menu
+        else
         {
             TOOL_EVENT evt( TC_COMMAND, TA_CHOICE_MENU_CHOICE, -1 );
             evt.SetHasPosition( false );
