@@ -1,7 +1,7 @@
 /*
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
- * Copyright (C) 2018-2023 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 2018-2024 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -62,16 +62,24 @@ enum
 
 static wxString netList( SCH_SYMBOL* aSymbol, SCH_SHEET_PATH& aSheetPath )
 {
+    wxCHECK( aSymbol && aSymbol->GetLibSymbolRef(), wxEmptyString );
+
     /*
      * Symbol netlist format:
-     *   pinCount
-     *   fpFilters
+     *   pinNumber pinName <tab> pinNumber pinName...
+     *   fpFilter fpFilter...
      */
     wxString netlist;
 
-    netlist << wxString::Format( wxS( "%zu\r" ), aSymbol->GetFullPinCount() );
+    wxArrayString pins;
 
-    wxCHECK( aSymbol && aSymbol->GetLibSymbolRef(), wxEmptyString );
+    for( SCH_PIN* pin : aSymbol->GetPins( &aSheetPath ) )
+        pins.push_back( pin->GetNumber() + ' ' + pin->GetShownName() );
+
+    if( !pins.IsEmpty() )
+        netlist << EscapeString( wxJoin( pins, '\t' ), CTX_LINE );
+
+    netlist << wxS( "\r" );
 
     wxArrayString fpFilters = aSymbol->GetLibSymbolRef()->GetFPFilters();
 
@@ -84,6 +92,40 @@ static wxString netList( SCH_SYMBOL* aSymbol, SCH_SHEET_PATH& aSheetPath )
 }
 
 
+static wxString netList( LIB_SYMBOL* aSymbol )
+{
+    /*
+     * Symbol netlist format:
+     *   pinNumber pinName <tab> pinNumber pinName...
+     *   fpFilter fpFilter...
+     */
+    wxString netlist;
+
+    std::vector<LIB_PIN*> pinList;
+
+    aSymbol->GetPins( pinList, 0, 1 );   // All units, but a single convert
+
+    wxArrayString pins;
+
+    for( LIB_PIN* pin : pinList )
+        pins.push_back( pin->GetNumber() + ' ' + pin->GetShownName() );
+
+    if( !pins.IsEmpty() )
+        netlist << EscapeString( wxJoin( pins, '\t' ), CTX_LINE );
+
+    netlist << wxS( "\r" );
+
+    wxArrayString fpFilters = aSymbol->GetFPFilters();
+
+    if( !fpFilters.IsEmpty() )
+        netlist << EscapeString( wxJoin( fpFilters, ' ' ), CTX_LINE );
+
+    netlist << wxS( "\r" );
+
+    return netlist;
+}
+
+
 template <class T>
 FIELDS_GRID_TABLE<T>::FIELDS_GRID_TABLE( DIALOG_SHIM* aDialog, SCH_BASE_FRAME* aFrame,
                                          WX_GRID* aGrid, LIB_SYMBOL* aSymbol ) :
@@ -93,6 +135,7 @@ FIELDS_GRID_TABLE<T>::FIELDS_GRID_TABLE( DIALOG_SHIM* aDialog, SCH_BASE_FRAME* a
         m_parentType( SCH_SYMBOL_T ),
         m_mandatoryFieldCount( MANDATORY_FIELDS ),
         m_part( aSymbol ),
+        m_symbolNetlist( netList( aSymbol ) ),
         m_fieldNameValidator( FIELD_NAME ),
         m_referenceValidator( REFERENCE_FIELD ),
         m_valueValidator( VALUE_FIELD ),
@@ -432,8 +475,9 @@ wxGridCellAttr* FIELDS_GRID_TABLE<T>::GetAttr( int aRow, int aCol, wxGridCellAtt
         else if( m_parentType == SCH_SYMBOL_T && aRow == FOOTPRINT_FIELD )
         {
             // Power symbols have do not appear in the board, so don't allow
-            // a footprint
-            if( m_part->IsPower() )
+            // a footprint (m_part can be nullptr when loading a old schematic
+            // (for instance Kicad 4) with libraries missing)
+            if( m_part && m_part->IsPower() )
             {
                 m_readOnlyAttr->IncRef();
                 return m_readOnlyAttr;
