@@ -332,7 +332,12 @@ SCH_FIELD::GetRenderCache( const wxString& forResolvedText, const VECTOR2I& forP
             VECTOR2I delta = forPosition - m_renderCachePos;
 
             for( std::unique_ptr<KIFONT::GLYPH>& glyph : m_renderCache )
-                static_cast<KIFONT::OUTLINE_GLYPH*>( glyph.get() )->Move( delta );
+            {
+                if( glyph->IsOutline() )
+                    static_cast<KIFONT::OUTLINE_GLYPH*>( glyph.get() )->Move( delta );
+                else
+                    static_cast<KIFONT::STROKE_GLYPH*>( glyph.get() )->Move( delta );
+            }
 
             m_renderCachePos = forPosition;
         }
@@ -1400,6 +1405,10 @@ static struct SCH_FIELD_DESC
         propMgr.Mask( TYPE_HASH( SCH_FIELD ), TYPE_HASH( EDA_TEXT ), _HKI( "Width" ) );
         propMgr.Mask( TYPE_HASH( SCH_FIELD ), TYPE_HASH( EDA_TEXT ), _HKI( "Height" ) );
 
+        propMgr.AddProperty( new PROPERTY<SCH_FIELD, int>( _HKI( "Text Size" ),
+                &SCH_FIELD::SetSchTextSize, &SCH_FIELD::GetSchTextSize, PROPERTY_DISPLAY::PT_SIZE ),
+                _HKI( "Text Properties" ) );
+
         propMgr.Mask( TYPE_HASH( SCH_FIELD ), TYPE_HASH( EDA_TEXT ), _HKI( "Orientation" ) );
 
         auto isNotNamedVariable =
