@@ -2,7 +2,7 @@
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
  * Copyright (C) 2015 Jean-Pierre Charras, jp.charras at wanadoo.fr
- * Copyright (C) 1992-2023 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 1992-2024 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,6 +33,9 @@
 #include <sch_symbol.h>
 #include <sch_sheet_path.h>
 #include <schematic.h>
+#include <sim/sim_model.h>
+#include <sim/spice_generator.h>
+#include <sim/sim_lib_mgr.h>
 #include <trace_helpers.h>
 #include <trigo.h>
 #include <refdes_utils.h>
@@ -767,7 +770,6 @@ const wxString SCH_SYMBOL::GetRef( const SCH_SHEET_PATH* sheet, bool aIncludeUni
     // the same symbol references, but perhaps this is best.
     if( ref.IsEmpty() && !GetField( REFERENCE_FIELD )->GetText().IsEmpty() )
     {
-        const_cast<SCH_SYMBOL*>( this )->SetRef( sheet, GetField( REFERENCE_FIELD )->GetText() );
         ref = GetField( REFERENCE_FIELD )->GetText();
     }
 
@@ -1285,7 +1287,7 @@ bool SCH_SYMBOL::ResolveTextVar( const SCH_SHEET_PATH* aPath, wxString* token, i
 {
     static wxRegEx operatingPoint( wxT( "^"
                                         "OP"
-                                        "(:[a-zA-Z]*)?"            // port
+                                        "(:[^.]*)?"                // pin
                                         "(.([0-9])?([a-zA-Z]*))?"  // format
                                         "$" ) );
 
@@ -1298,26 +1300,66 @@ bool SCH_SYMBOL::ResolveTextVar( const SCH_SHEET_PATH* aPath, wxString* token, i
 
     if( operatingPoint.Matches( *token ) )
     {
-        wxString port( operatingPoint.GetMatch( *token, 1 ) );
+        wxString pin( operatingPoint.GetMatch( *token, 1 ).Lower() );
         wxString precisionStr( operatingPoint.GetMatch( *token, 3 ) );
         wxString range( operatingPoint.GetMatch( *token, 4 ) );
-
-        wxString signal = GetRef( aPath ) + port;
         int      precision = 3;
 
         if( !precisionStr.IsEmpty() )
             precision = precisionStr[0] - '0';
 
         if( range.IsEmpty() )
+            range = wxS( "~A" );
+
+        SIM_LIB_MGR   simLibMgr( &schematic->Prj() );
+        NULL_REPORTER devnull;
+        SIM_MODEL&    model = simLibMgr.CreateModel( aPath, const_cast<SCH_SYMBOL&>( *this ),
+                                                     devnull ).model;
+        SPICE_ITEM spiceItem;
+        spiceItem.refName = GetRef( aPath );
+
+        wxString spiceRef = model.SpiceGenerator().ItemName( spiceItem );
+        spiceRef = spiceRef.Lower();
+
+        if( pin.IsEmpty() )
         {
-            if( port == wxS( ":power" ) )
+            *token = schematic->GetOperatingPoint( spiceRef, precision, range );
+            return true;
+        }
+        else if( pin == wxS( ":power" ) )
+        {
+            if( range.IsEmpty() )
                 range = wxS( "~W" );
-            else
-                range = wxS( "~A" );
+
+            *token = schematic->GetOperatingPoint( spiceRef + wxS( ":power" ), precision, range );
+            return true;
+        }
+        else
+        {
+            pin = pin.SubString( 1, -1 );   // Strip ':' from front
+
+            for( const std::reference_wrapper<const SIM_MODEL::PIN>& modelPin : model.GetPins() )
+            {
+                SCH_PIN* symbolPin = GetPin( modelPin.get().symbolPinNumber );
+
+                if( pin == symbolPin->GetName().Lower() || pin == symbolPin->GetNumber().Lower() )
+                {
+                    if( model.GetPins().size() == 2 )
+                    {
+                        *token = schematic->GetOperatingPoint( spiceRef, precision, range );
+                    }
+                    else
+                    {
+                        wxString signalName = spiceRef + wxS( ":" ) + modelPin.get().name;
+                        *token = schematic->GetOperatingPoint( signalName, precision, range );
+                    }
+
+                    return true;
+                }
+            }
         }
 
-        *token = schematic->GetOperatingPoint( signal.Lower(), precision, range );
-
+        *token = wxS( "?" );
         return true;
     }
 
@@ -2055,8 +2097,9 @@ void SCH_SYMBOL::GetEndPoints( std::vector <DANGLING_END_ITEM>& aItemList )
 }
 
 
-bool SCH_SYMBOL::UpdateDanglingState( std::vector<DANGLING_END_ITEM>& aItemList,
-                                      const SCH_SHEET_PATH* aPath )
+bool SCH_SYMBOL::UpdateDanglingState( std::vector<DANGLING_END_ITEM>& aItemListByType,
+                                      std::vector<DANGLING_END_ITEM>& aItemListByPos,
+                                      const SCH_SHEET_PATH*           aPath )
 {
     bool changed = false;
 
@@ -2067,8 +2110,12 @@ bool SCH_SYMBOL::UpdateDanglingState( std::vector<DANGLING_END_ITEM>& aItemList,
 
         VECTOR2I pos = m_transform.TransformCoordinate( pin->GetLocalPosition() ) + m_pos;
 
-        for( DANGLING_END_ITEM& each_item : aItemList )
+        auto lower = DANGLING_END_ITEM_HELPER::get_lower_pos( aItemListByPos, pos );
+        bool do_break = false;
+
+        for( auto it = lower; it < aItemListByPos.end() && it->GetPosition() == pos; it++ )
         {
+            DANGLING_END_ITEM& each_item = *it;
             // Some people like to stack pins on top of each other in a symbol to indicate
             // internal connection. While technically connected, it is not particularly useful
             // to display them that way, so skip any pins that are in the same symbol as this
@@ -2084,17 +2131,15 @@ bool SCH_SYMBOL::UpdateDanglingState( std::vector<DANGLING_END_ITEM>& aItemList,
             case WIRE_END:
             case NO_CONNECT_END:
             case JUNCTION_END:
-
-                if( pos == each_item.GetPosition() )
-                    pin->SetIsDangling( false );
-
+                pin->SetIsDangling( false );
+                do_break = true;
                 break;
 
             default:
                 break;
             }
 
-            if( !pin->IsDangling() )
+            if( do_break )
                 break;
         }
 
@@ -2114,6 +2159,48 @@ VECTOR2I SCH_SYMBOL::GetPinPhysicalPosition( const LIB_PIN* Pin ) const
 }
 
 
+bool SCH_SYMBOL::HasConnectivityChanges( const SCH_ITEM* aItem,
+                                         const SCH_SHEET_PATH* aInstance ) const
+{
+    // Do not compare to ourself.
+    if( aItem == this )
+        return false;
+
+    const SCH_SYMBOL* symbol = dynamic_cast<const SCH_SYMBOL*>( aItem );
+
+    // Don't compare against a different SCH_ITEM.
+    wxCHECK( symbol, false );
+
+    if( GetPosition() != symbol->GetPosition() )
+        return true;
+
+    if( GetLibId() != symbol->GetLibId() )
+        return true;
+
+    if( GetUnitSelection( aInstance ) != symbol->GetUnitSelection( aInstance ) )
+        return true;
+
+    if( GetRef( aInstance ) != symbol->GetRef( aInstance ) )
+        return true;
+
+    // Power symbol value field changes are connectivity changes.
+    if( IsPower()
+      && ( GetValueFieldText( true, aInstance, false ) != symbol->GetValueFieldText( true, aInstance, false ) ) )
+        return true;
+
+    if( m_pins.size() != symbol->m_pins.size() )
+        return true;
+
+    for( size_t i = 0; i < m_pins.size(); i++ )
+    {
+        if( m_pins[i]->HasConnectivityChanges( symbol->m_pins[i].get() ) )
+            return true;
+    }
+
+    return false;
+}
+
+
 std::vector<VECTOR2I> SCH_SYMBOL::GetConnectionPoints() const
 {
     std::vector<VECTOR2I> retval;
