@@ -2,7 +2,7 @@
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
  * Copyright (C) 2015 Jean-Pierre Charras, jp.charras at wanadoo.fr
- * Copyright (C) 2004-2022 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 2004-2024 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -589,13 +589,15 @@ bool SCH_EDIT_FRAME::LoadSheetFromFile( SCH_SHEET* aSheet, SCH_SHEET_PATH* aCurr
 
 
 bool SCH_EDIT_FRAME::EditSheetProperties( SCH_SHEET* aSheet, SCH_SHEET_PATH* aHierarchy,
-                                          bool* aClearAnnotationNewItems )
+                                          bool* aClearAnnotationNewItems,
+                                          bool* aUpdateHierarchyNavigator )
 {
     if( aSheet == nullptr || aHierarchy == nullptr )
         return false;
 
     // Get the new texts
-    DIALOG_SHEET_PROPERTIES dlg( this, aSheet, aClearAnnotationNewItems );
+    DIALOG_SHEET_PROPERTIES dlg( this, aSheet, aClearAnnotationNewItems,
+                                 aUpdateHierarchyNavigator );
 
     if( dlg.ShowModal() == wxID_CANCEL )
         return false;
