@@ -50,6 +50,7 @@
 #include <dialogs/dialog_sim_format_value.h>
 #include <eeschema_settings.h>
 #include "kiplatform/app.h"
+#include "wx/clipbrd.h"
 
 
 SIM_TRACE_TYPE operator|( SIM_TRACE_TYPE aFirst, SIM_TRACE_TYPE aSecond )
@@ -168,11 +169,12 @@ void SIGNALS_GRID_TRICKS::showPopupMenu( wxMenu& menu, wxGridEvent& aEvent )
                 }
 
                 menu.AppendSeparator();
+                menu.Append( GRIDTRICKS_ID_COPY, _( "Copy Signal Name" ) + "\tCtrl+C" );
+
+                m_grid->PopupMenu( &menu );
             }
         }
     }
-
-    GRID_TRICKS::showPopupMenu( menu, aEvent );
 }
 
 
@@ -283,9 +285,25 @@ void SIGNALS_GRID_TRICKS::doPopupSelection( wxCommandEvent& event )
         for( const wxString& signal : signals )
             m_parent->DoFourier( signal, fundamental );
     }
-    else
+    else if( event.GetId() == GRIDTRICKS_ID_COPY )
     {
-        GRID_TRICKS::doPopupSelection( event );
+        wxLogNull doNotLog; // disable logging of failed clipboard actions
+        wxString  txt;
+
+        for( const wxString& signal : signals )
+        {
+            if( !txt.IsEmpty() )
+                txt += '\r';
+
+            txt += signal;
+        }
+
+        if( wxTheClipboard->Open() )
+        {
+            wxTheClipboard->SetData( new wxTextDataObject( txt ) );
+            wxTheClipboard->Flush(); // Allow data to be available after closing KiCad
+            wxTheClipboard->Close();
+        }
     }
 }
 
@@ -899,10 +917,13 @@ void SIMULATOR_FRAME_UI::rebuildSignalsList()
             if( !name.StartsWith( "V" ) )
                 continue;
 
-            const SIM_MODEL::PARAM* portNum = item.model->FindParam( "portnum" );
+            std::string portnum = "";
 
-            if( portNum )
-                portnums.push_back( SIM_VALUE::ToSpice( portNum->value ) );
+            if( const SIM_MODEL::PARAM* portnum_param = item.model->FindParam( "portnum" ) )
+                portnum = SIM_VALUE::ToSpice( portnum_param->value );
+
+            if( portnum != "" )
+                portnums.push_back( portnum );
         }
 
         for( const std::string& portnum1 : portnums )
@@ -1230,7 +1251,10 @@ void SIMULATOR_FRAME_UI::OnUpdateUI( wxUpdateUIEvent& event )
     if( SIM_PLOT_TAB* plotTab = dynamic_cast<SIM_PLOT_TAB*>( GetCurrentSimTab() ) )
     {
         if( plotTab->GetLegendPosition() != plotTab->m_LastLegendPosition )
+        {
+            plotTab->m_LastLegendPosition = plotTab->GetLegendPosition();
             OnModify();
+        }
     }
 }
 
@@ -2792,9 +2816,12 @@ void SIMULATOR_FRAME_UI::OnSimRefresh( bool aFinal )
             m_simConsole->AppendText( msg );
             m_simConsole->SetInsertionPointEnd();
 
-            if( signal.StartsWith( wxS( "V(" ) ) || signal.StartsWith( wxS( "I(" ) ) )
+            if( type == SPT_VOLTAGE || type == SPT_CURRENT || type == SPT_POWER )
                 signal = signal.SubString( 2, signal.Length() - 2 );
 
+            if( type == SPT_POWER )
+                signal += wxS( ":power" );
+
             m_schematicFrame->Schematic().SetOperatingPoint( signal, val_list.at( 0 ) );
         }
     }
