@@ -2,7 +2,7 @@
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
  * Copyright (C) 2019 CERN
- * Copyright (C) 2019-2023 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 2019-2024 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1055,8 +1055,35 @@ bool EE_SELECTION_TOOL::CollectHits( EE_COLLECTOR& aCollector, const VECTOR2I& a
 void EE_SELECTION_TOOL::narrowSelection( EE_COLLECTOR& collector, const VECTOR2I& aWhere,
                                          bool aCheckLocked, bool aSelectedOnly )
 {
+    SYMBOL_EDIT_FRAME* symbolEditorFrame = dynamic_cast<SYMBOL_EDIT_FRAME*>( m_frame );
+
     for( int i = collector.GetCount() - 1; i >= 0; --i )
     {
+        if( symbolEditorFrame )
+        {
+            // Do not select invisible items if they are not displayed
+            EDA_ITEM* item = static_cast<EDA_ITEM*>( collector[i] );
+
+            if( item->Type() == LIB_FIELD_T )
+            {
+                if( !static_cast<LIB_FIELD*>( item )->IsVisible()
+                    && !symbolEditorFrame->GetShowInvisibleFields() )
+                {
+                    collector.Remove( i );
+                    continue;
+                }
+            }
+            else if( item->Type() == LIB_PIN_T )
+            {
+                if( !static_cast<LIB_PIN*>( item )->IsVisible()
+                    && !symbolEditorFrame->GetShowInvisiblePins() )
+                {
+                    collector.Remove( i );
+                    continue;
+                }
+            }
+        }
+
         if( !Selectable( collector[i], &aWhere ) )
         {
             collector.Remove( i );
@@ -1348,12 +1375,12 @@ void EE_SELECTION_TOOL::GuessSelectionCandidates( EE_COLLECTOR& collector, const
     SEG       poss( m_isSymbolEditor ? mapCoords( pos ) : pos,
                     m_isSymbolEditor ? mapCoords( pos ) : pos );
     EDA_ITEM* closest = nullptr;
-    int       closestDist = INT_MAX / 2;
+    int       closestDist = INT_MAX / 4;
 
     for( EDA_ITEM* item : collector )
     {
         BOX2I bbox = item->GetBoundingBox();
-        int   dist = INT_MAX / 2;
+        int   dist = INT_MAX / 4;
 
         if( exactHits.count( item ) )
         {
@@ -1366,6 +1393,7 @@ void EE_SELECTION_TOOL::GuessSelectionCandidates( EE_COLLECTOR& collector, const
             SCH_LINE*   line = dynamic_cast<SCH_LINE*>( item );
             SCH_FIELD*  field = dynamic_cast<SCH_FIELD*>( item );
             EDA_TEXT*   text = dynamic_cast<EDA_TEXT*>( item );
+            EDA_SHAPE*  shape = dynamic_cast<EDA_SHAPE*>( item );
             SCH_SYMBOL* symbol = dynamic_cast<SCH_SYMBOL*>( item );
 
             if( line )
@@ -1389,12 +1417,27 @@ void EE_SELECTION_TOOL::GuessSelectionCandidates( EE_COLLECTOR& collector, const
                     }
                 }
 
-                field->GetEffectiveTextShape( false, box, orient )->Collide( poss, INT_MAX / 2,
-                                                                             &dist );
+                field->GetEffectiveTextShape( false, box, orient )
+                        ->Collide( poss, INT_MAX / 4, &dist );
             }
             else if( text )
             {
-                text->GetEffectiveTextShape( false )->Collide( poss, INT_MAX / 2, &dist );
+                text->GetEffectiveTextShape( false )->Collide( poss, INT_MAX / 4, &dist );
+            }
+            else if( shape )
+            {
+                std::vector<SHAPE*> shapes = shape->MakeEffectiveShapes();
+
+                for( SHAPE* s : shapes )
+                {
+                    int shapeDist = dist;
+                    s->Collide( poss, INT_MAX / 4, &shapeDist );
+
+                    if( shapeDist < dist )
+                        dist = shapeDist;
+
+                    delete s;
+                }
             }
             else if( symbol )
             {
