@@ -2,7 +2,7 @@
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
  * Copyright (C) 2019-2023 CERN
- * Copyright (C) 2019-2023 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 2019-2024 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -466,7 +466,8 @@ int SCH_DRAWING_TOOLS::PlaceSymbol( const TOOL_EVENT& aEvent )
                 }
             }
         }
-        else if( evt->IsAction( &ACTIONS::duplicate ) )
+        else if( evt->IsAction( &ACTIONS::duplicate )
+                 || evt->IsAction( &EE_ACTIONS::repeatDrawItem ) )
         {
             if( symbol )
             {
@@ -724,6 +725,21 @@ int SCH_DRAWING_TOOLS::PlaceImage( const TOOL_EVENT& aEvent )
 
             m_menu.ShowContextMenu( m_selectionTool->GetSelection() );
         }
+        else if( evt->IsAction( &ACTIONS::duplicate )
+                 || evt->IsAction( &EE_ACTIONS::repeatDrawItem ) )
+        {
+            if( image )
+            {
+                // This doesn't really make sense; we'll just end up dragging a stack of
+                // objects so we ignore the duplicate and just carry on.
+                wxBell();
+                continue;
+            }
+
+            // Exit.  The duplicate will run in its own loop.
+            m_frame->PopTool( aEvent );
+            break;
+        }
         else if( image && ( evt->IsAction( &ACTIONS::refreshPreview ) || evt->IsMotion() ) )
         {
             image->SetPosition( cursorPos );
@@ -1686,6 +1702,21 @@ int SCH_DRAWING_TOOLS::TwoClickPlace( const TOOL_EVENT& aEvent )
                 item = nullptr;
             }
         }
+        else if( evt->IsAction( &ACTIONS::duplicate )
+                 || evt->IsAction( &EE_ACTIONS::repeatDrawItem ) )
+        {
+            if( item )
+            {
+                // This doesn't really make sense; we'll just end up dragging a stack of
+                // objects so we ignore the duplicate and just carry on.
+                wxBell();
+                continue;
+            }
+
+            // Exit.  The duplicate will run in its own loop.
+            m_frame->PopTool( aEvent );
+            break;
+        }
         else if( item && ( evt->IsAction( &ACTIONS::refreshPreview ) || evt->IsMotion() ) )
         {
             item->SetPosition( cursorPos );
@@ -1916,6 +1947,21 @@ int SCH_DRAWING_TOOLS::DrawShape( const TOOL_EVENT& aEvent )
                 m_toolMgr->PostAction( ACTIONS::activatePointEditor );
             }
         }
+        else if( evt->IsAction( &ACTIONS::duplicate )
+                 || evt->IsAction( &EE_ACTIONS::repeatDrawItem ) )
+        {
+            if( item )
+            {
+                // This doesn't really make sense; we'll just end up dragging a stack of
+                // objects so we ignore the duplicate and just carry on.
+                wxBell();
+                continue;
+            }
+
+            // Exit.  The duplicate will run in its own loop.
+            m_frame->PopTool( aEvent );
+            break;
+        }
         else if( item && ( evt->IsAction( &ACTIONS::refreshPreview ) || evt->IsMotion() ) )
         {
             item->CalcEdit( cursorPos );
@@ -1956,29 +2002,6 @@ int SCH_DRAWING_TOOLS::DrawShape( const TOOL_EVENT& aEvent )
 }
 
 
-void SCH_DRAWING_TOOLS::initSharedInstancePageNumbers( const SCH_SHEET_PATH& aAddedSheet )
-{
-    SCH_SHEET_LIST fullHierarchy = m_frame->Schematic().GetFullHierarchy();
-    SCH_SHEET_LIST instances = fullHierarchy.FindAllSheetsForScreen( aAddedSheet.LastScreen() );
-
-    long pageNo;
-    long addedSheetPageNo;
-
-    if( aAddedSheet.GetPageNumber().ToLong( &addedSheetPageNo ) )
-        pageNo = addedSheetPageNo + 1;
-    else
-        pageNo = (signed)( fullHierarchy.size() - instances.size() + 1 );
-
-    for( SCH_SHEET_PATH& sheet : instances )
-    {
-        if( sheet == aAddedSheet )
-            continue;
-
-        sheet.SetPageNumber( wxString::Format( wxS( "%ld" ), pageNo++ ) );
-    }
-}
-
-
 int SCH_DRAWING_TOOLS::DrawSheet( const TOOL_EVENT& aEvent )
 {
     SCH_SHEET* sheet = nullptr;
@@ -2138,7 +2161,6 @@ int SCH_DRAWING_TOOLS::DrawSheet( const TOOL_EVENT& aEvent )
 
                 SCH_SHEET_PATH newPath = m_frame->GetCurrentSheet();
                 newPath.push_back( sheet );
-                initSharedInstancePageNumbers( newPath );
 
                 m_frame->UpdateHierarchyNavigator();
                 m_selectionTool->AddItemToSel( sheet );
@@ -2151,6 +2173,21 @@ int SCH_DRAWING_TOOLS::DrawSheet( const TOOL_EVENT& aEvent )
 
             sheet = nullptr;
         }
+        else if( evt->IsAction( &ACTIONS::duplicate )
+                 || evt->IsAction( &EE_ACTIONS::repeatDrawItem ) )
+        {
+            if( sheet )
+            {
+                // This doesn't really make sense; we'll just end up dragging a stack of
+                // objects so we ignore the duplicate and just carry on.
+                wxBell();
+                continue;
+            }
+
+            // Exit.  The duplicate will run in its own loop.
+            m_frame->PopTool( aEvent );
+            break;
+        }
         else if( sheet && ( evt->IsAction( &ACTIONS::refreshPreview ) || evt->IsMotion() ) )
         {
             sizeSheet( sheet, cursorPos );
