@@ -2,7 +2,7 @@
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
  * Copyright (C) 2019 CERN
- * Copyright (C) 2019-2023 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 2019-2024 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -586,8 +586,14 @@ bool SCH_MOVE_TOOL::doMoveSelection( const TOOL_EVENT& aEvent, SCH_COMMIT* aComm
                     for( EDA_ITEM* item : selection )
                         static_cast<SCH_ITEM*>( item )->GetEndPoints( internalPoints );
 
+                    std::vector<DANGLING_END_ITEM> endPointsByType = internalPoints;
+                    std::vector<DANGLING_END_ITEM> endPointsByPos = endPointsByType;
+                    DANGLING_END_ITEM_HELPER::sort_dangling_end_items( endPointsByType,
+                                                                       endPointsByPos );
+
                     for( EDA_ITEM* item : selection )
-                        static_cast<SCH_ITEM*>( item )->UpdateDanglingState( internalPoints );
+                        static_cast<SCH_ITEM*>( item )->UpdateDanglingState( endPointsByType,
+                                                                             endPointsByPos );
                 }
 
 
@@ -1578,7 +1584,7 @@ void SCH_MOVE_TOOL::moveItem( EDA_ITEM* aItem, const VECTOR2I& aDelta )
 }
 
 
-int SCH_MOVE_TOOL::AlignElements( const TOOL_EVENT& aEvent )
+int SCH_MOVE_TOOL::AlignToGrid( const TOOL_EVENT& aEvent )
 {
     EE_GRID_HELPER    grid( m_toolMgr);
     EE_SELECTION&     selection = m_selectionTool->RequestSelection( EE_COLLECTOR::MovableItems );
@@ -1682,7 +1688,7 @@ int SCH_MOVE_TOOL::AlignElements( const TOOL_EVENT& aEvent )
                 else
                     newPos = pin->GetPosition() + br_delta;
 
-                VECTOR2I delta = grid.AlignGrid( newPos, selectionGrid ) - pin->GetPosition();
+                VECTOR2I delta = grid.AlignGrid( newPos - pin->GetPosition(), selectionGrid );
 
                 if( delta != VECTOR2I( 0, 0 ) )
                 {
@@ -1750,7 +1756,7 @@ int SCH_MOVE_TOOL::AlignElements( const TOOL_EVENT& aEvent )
     m_toolMgr->PostEvent( EVENTS::SelectedItemsMoved );
 
     m_frame->SchematicCleanUp( &commit );
-    commit.Push( _( "Align" ) );
+    commit.Push( _( "Align Items to Grid" ) );
     return 0;
 }
 
@@ -1772,7 +1778,7 @@ void SCH_MOVE_TOOL::setTransitions()
 {
     Go( &SCH_MOVE_TOOL::Main,               EE_ACTIONS::move.MakeEvent() );
     Go( &SCH_MOVE_TOOL::Main,               EE_ACTIONS::drag.MakeEvent() );
-    Go( &SCH_MOVE_TOOL::AlignElements,      EE_ACTIONS::alignToGrid.MakeEvent() );
+    Go( &SCH_MOVE_TOOL::AlignToGrid,        EE_ACTIONS::alignToGrid.MakeEvent() );
 }
 
 
