@@ -45,6 +45,7 @@ class SHAPE;
 const ssize_t                     SHAPE_LINE_CHAIN::SHAPE_IS_PT = -1;
 const std::pair<ssize_t, ssize_t> SHAPE_LINE_CHAIN::SHAPES_ARE_PT = { SHAPE_IS_PT, SHAPE_IS_PT };
 
+
 SHAPE_LINE_CHAIN::SHAPE_LINE_CHAIN( const std::vector<int>& aV)
     : SHAPE_LINE_CHAIN_BASE( SH_LINE_CHAIN ), m_closed( false ), m_width( 0 )
 {
@@ -55,6 +56,27 @@ SHAPE_LINE_CHAIN::SHAPE_LINE_CHAIN( const std::vector<int>& aV)
 }
 
 
+SHAPE_LINE_CHAIN::SHAPE_LINE_CHAIN( const std::vector<VECTOR2I>& aV, bool aClosed ) :
+        SHAPE_LINE_CHAIN_BASE( SH_LINE_CHAIN ),
+        m_closed( false ),
+        m_width( 0 )
+{
+    m_points = aV;
+    m_shapes = std::vector<std::pair<ssize_t, ssize_t>>( aV.size(), SHAPES_ARE_PT );
+    SetClosed( aClosed );
+}
+
+
+SHAPE_LINE_CHAIN::SHAPE_LINE_CHAIN( const SHAPE_ARC& aArc, bool aClosed ) :
+        SHAPE_LINE_CHAIN_BASE( SH_LINE_CHAIN ),
+        m_closed( false ),
+        m_width( aArc.GetWidth() )
+{
+    Append( aArc );
+    SetClosed( aClosed );
+}
+
+
 SHAPE_LINE_CHAIN::SHAPE_LINE_CHAIN( const ClipperLib::Path&             aPath,
                                     const std::vector<CLIPPER_Z_VALUE>& aZValueBuffer,
                                     const std::vector<SHAPE_ARC>&       aArcBuffer ) :
@@ -219,11 +241,9 @@ void SHAPE_LINE_CHAIN::fixIndicesRotation()
         return;
 
     size_t rotations = 0;
-    size_t numPoints = m_points.size();
 
     while( ArcIndex( 0 ) != SHAPE_IS_PT
-        && ArcIndex( 0 ) == ArcIndex( numPoints - 1 )
-        && !IsSharedPt( 0 ) )
+        && !IsArcStart( 0 ) )
     {
         // Rotate right
         std::rotate( m_points.rbegin(), m_points.rbegin() + 1, m_points.rend() );
@@ -242,10 +262,10 @@ void SHAPE_LINE_CHAIN::mergeFirstLastPointIfNeeded()
     {
         if( m_points.size() > 1 && m_points.front() == m_points.back() )
         {
-            if( m_shapes.back() != SHAPES_ARE_PT )
+            if( ArcIndex( m_shapes.size() - 1 ) != SHAPE_IS_PT )
             {
                 m_shapes.front().second = m_shapes.front().first;
-                m_shapes.front().first = m_shapes.back().first;
+                m_shapes.front().first = ArcIndex( m_shapes.size() - 1 ) ;
             }
 
             m_points.pop_back();
@@ -635,6 +655,9 @@ bool SHAPE_LINE_CHAIN::Collide( const SEG& aSeg, int aClearance, int* aActual,
         return true;
     }
 
+    int dist = 0;
+    int closest_dist = sqrt( closest_dist_sq );
+
     // Collide arc segments
     for( size_t i = 0; i < ArcCount(); i++ )
     {
@@ -643,8 +666,28 @@ bool SHAPE_LINE_CHAIN::Collide( const SEG& aSeg, int aClearance, int* aActual,
         // The arcs in the chain should have zero width
         wxASSERT_MSG( arc.GetWidth() == 0, wxT( "Invalid arc width - should be zero" ) );
 
-        if( arc.Collide( aSeg, aClearance, aActual, aLocation ) )
-            return true;
+        if( arc.Collide( aSeg, aClearance, aActual || aLocation ? &dist : nullptr,
+                         aLocation ? &nearest : nullptr ) )
+        {
+            if( !aActual )
+                return true;
+
+            if( dist < closest_dist )
+            {
+                closest_dist = dist;
+            }
+        }
+    }
+
+    if( closest_dist_sq == 0 || closest_dist_sq < clearance_sq )
+    {
+        if( aLocation )
+            *aLocation = nearest;
+
+        if( aActual )
+            *aActual = sqrt( closest_dist_sq );
+
+        return true;
     }
 
     return false;
@@ -1781,108 +1824,6 @@ const std::optional<SHAPE_LINE_CHAIN::INTERSECTION> SHAPE_LINE_CHAIN::SelfInters
 }
 
 
-SHAPE_LINE_CHAIN& SHAPE_LINE_CHAIN::Simplify( bool aRemoveColinear )
-{
-    std::vector<VECTOR2I> pts_unique;
-    std::vector<std::pair<ssize_t, ssize_t>> shapes_unique;
-
-    // Always try to keep at least 2 points otherwise, we're not really a line
-    if( PointCount() < 3 )
-    {
-        return *this;
-    }
-    else if( PointCount() == 3 )
-    {
-        if( m_points[0] == m_points[1] )
-            Remove( 1 );
-
-        return *this;
-    }
-
-    int i = 0;
-    int np = PointCount();
-
-    // stage 1: eliminate duplicate vertices
-    while( i < np )
-    {
-        int j = i + 1;
-
-        // We can eliminate duplicate vertices as long as they are part of the same shape, OR if
-        // one of them is part of a shape and one is not.
-        while( j < np && m_points[i] == m_points[j] &&
-               ( m_shapes[i] == m_shapes[j] ||
-                 m_shapes[i] == SHAPES_ARE_PT ||
-                 m_shapes[j] == SHAPES_ARE_PT ) )
-        {
-            j++;
-        }
-
-        std::pair<ssize_t,ssize_t> shapeToKeep = m_shapes[i];
-
-        if( shapeToKeep == SHAPES_ARE_PT )
-            shapeToKeep = m_shapes[j - 1];
-
-        assert( shapeToKeep.first < static_cast<int>( m_arcs.size() ) );
-        assert( shapeToKeep.second < static_cast<int>( m_arcs.size() ) );
-
-        pts_unique.push_back( CPoint( i ) );
-        shapes_unique.push_back( shapeToKeep );
-
-        i = j;
-    }
-
-    m_points.clear();
-    m_shapes.clear();
-    np = pts_unique.size();
-
-    i = 0;
-
-    // stage 2: eliminate colinear segments
-    while( i < np - 2 )
-    {
-        const VECTOR2I p0 = pts_unique[i];
-        int n = i;
-
-        if( aRemoveColinear && shapes_unique[i] == SHAPES_ARE_PT
-            && shapes_unique[i + 1] == SHAPES_ARE_PT )
-        {
-            while( n < np - 2
-                    && ( SEG( p0, pts_unique[n + 2] ).LineDistance( pts_unique[n + 1] ) <= 1
-                      || SEG( p0, pts_unique[n + 2] ).Collinear( SEG( p0, pts_unique[n + 1] ) ) ) )
-                n++;
-        }
-
-        m_points.push_back( p0 );
-        m_shapes.push_back( shapes_unique[i] );
-
-        if( n > i )
-            i = n;
-
-        if( n == np - 2 )
-        {
-            m_points.push_back( pts_unique[np - 1] );
-            m_shapes.push_back( shapes_unique[np - 1] );
-            return *this;
-        }
-
-        i++;
-    }
-
-    if( np > 1 )
-    {
-        m_points.push_back( pts_unique[np - 2] );
-        m_shapes.push_back( shapes_unique[np - 2] );
-    }
-
-    m_points.push_back( pts_unique[np - 1] );
-    m_shapes.push_back( shapes_unique[np - 1] );
-
-    assert( m_points.size() == m_shapes.size() );
-
-    return *this;
-}
-
-
 const VECTOR2I SHAPE_LINE_CHAIN::NearestPoint( const VECTOR2I& aP,
                                                bool aAllowInternalShapePoints ) const
 {
@@ -2146,13 +2087,125 @@ double SHAPE_LINE_CHAIN::Area( bool aAbsolute ) const
 }
 
 
+void SHAPE_LINE_CHAIN::RemoveDuplicatePoints()
+{
+    std::vector<VECTOR2I> pts_unique;
+    std::vector<std::pair<ssize_t, ssize_t>> shapes_unique;
+
+    // Always try to keep at least 2 points otherwise, we're not really a line
+    if( PointCount() < 3 )
+    {
+        return;
+    }
+    else if( PointCount() == 3 )
+    {
+        if( m_points[0] == m_points[1] )
+            Remove( 1 );
+
+        return;
+    }
+
+    int i = 0;
+
+    while( i < PointCount() )
+    {
+        int j = i + 1;
+
+        // We can eliminate duplicate vertices as long as they are part of the same shape, OR if
+        // one of them is part of a shape and one is not.
+        while( j < PointCount() && m_points[i] == m_points[j] &&
+               ( m_shapes[i] == m_shapes[j] ||
+                 m_shapes[i] == SHAPES_ARE_PT ||
+                 m_shapes[j] == SHAPES_ARE_PT ) )
+        {
+            j++;
+        }
+
+        std::pair<ssize_t,ssize_t> shapeToKeep = m_shapes[i];
+
+        if( shapeToKeep == SHAPES_ARE_PT )
+            shapeToKeep = m_shapes[j - 1];
+
+        assert( shapeToKeep.first < static_cast<int>( m_arcs.size() ) );
+        assert( shapeToKeep.second < static_cast<int>( m_arcs.size() ) );
+
+        pts_unique.push_back( CPoint( i ) );
+        shapes_unique.push_back( shapeToKeep );
+
+        i = j;
+    }
+
+    m_points.clear();
+    m_shapes.clear();
+
+    for( size_t ii = 0; ii < pts_unique.size(); ++ii )
+    {
+        const VECTOR2I p0 = pts_unique[ii];
+
+        m_points.push_back( p0 );
+        m_shapes.push_back( shapes_unique[ii] );
+    }
+}
+
+
+
+void SHAPE_LINE_CHAIN::Simplify( int aMaxError )
+{
+    if( PointCount() < 3 )
+        return;
+
+    std::vector<VECTOR2I> new_points;
+    std::vector<std::pair<ssize_t, ssize_t>> new_shapes;
+
+    new_points.reserve( m_points.size() );
+    new_shapes.reserve( m_shapes.size() );
+
+    for( size_t ii = 0; ii < m_points.size(); )
+    {
+        new_points.push_back( m_points[ii] );
+        new_shapes.push_back( m_shapes[ii] );
+        size_t jj = ( ii + 1 ) % m_points.size();
+        size_t kk = ( jj + 1 ) % m_points.size();
+
+        if( m_shapes[ii].first != SHAPE_IS_PT || m_shapes[jj].first != SHAPE_IS_PT
+            || m_shapes[kk].first != SHAPE_IS_PT )
+        {
+            ++ii;
+            continue;
+        }
+
+        while( TestSegmentHitFast( m_points[jj], m_points[ii], m_points[kk], aMaxError )
+               && ii != kk && jj > ii )
+        {
+            jj = ( jj + 1 ) % m_points.size();
+            kk = ( jj + 1 ) % m_points.size();
+        }
+
+        if( ii == kk || jj <= ii )
+            break;
+
+        ii = jj;
+    }
+
+    // If we have only one point, we need to add a second point to make a line
+    if( new_points.size() == 1 )
+    {
+        new_points.push_back( m_points.back() );
+        new_shapes.push_back( m_shapes.back() );
+    }
+
+    m_points.clear();
+    m_shapes.clear();
+    m_points = new_points;
+    m_shapes = new_shapes;
+}
+
+
 void SHAPE_LINE_CHAIN::Split( const VECTOR2I& aStart, const VECTOR2I& aEnd, SHAPE_LINE_CHAIN& aPre,
                               SHAPE_LINE_CHAIN& aMid, SHAPE_LINE_CHAIN& aPost ) const
 {
     VECTOR2I cp( aEnd );
 
-    wxASSERT( cp != aStart );
-
     VECTOR2I n = NearestPoint( cp, false );
     VECTOR2I m = NearestPoint( aStart, false );
 
@@ -2399,3 +2452,74 @@ bool SHAPE_LINE_CHAIN::POINT_INSIDE_TRACKER::IsInside()
     processVertex( m_lastPoint, m_firstPoint );
     return m_state > 0;
 }
+
+
+bool SHAPE_LINE_CHAIN::IsSharedPt( size_t aIndex ) const
+{
+    return aIndex < m_shapes.size()
+           && m_shapes[aIndex].first != SHAPE_IS_PT
+           && m_shapes[aIndex].second != SHAPE_IS_PT;
+}
+
+
+bool SHAPE_LINE_CHAIN::IsPtOnArc( size_t aPtIndex ) const
+{
+    return aPtIndex < m_shapes.size() && m_shapes[aPtIndex] != SHAPES_ARE_PT;
+}
+
+
+bool SHAPE_LINE_CHAIN::IsArcSegment( size_t aSegment ) const
+{
+    /*
+     * A segment is part of an arc except in the special case of two arcs next to each other
+     * but without a shared vertex.  Here there is a segment between the end of the first arc
+     * and the start of the second arc.
+     */
+    size_t nextIdx = aSegment + 1;
+
+    if( nextIdx > m_shapes.size() - 1 )
+    {
+        if( nextIdx == m_shapes.size() && m_closed && IsSharedPt( 0 ) )
+            nextIdx = 0; // segment between end point and first point
+        else
+            return false;
+    }
+
+    return ( IsPtOnArc( aSegment )
+                 && ( ArcIndex( aSegment ) == m_shapes[nextIdx].first ) );
+}
+
+
+bool SHAPE_LINE_CHAIN::IsArcStart( size_t aIndex ) const
+{
+    if( !IsArcSegment( aIndex ) ) // also does bound checking
+        return false;
+
+    if( IsSharedPt( aIndex ) )
+        return true;
+
+    const SHAPE_ARC& arc = Arc( ArcIndex( aIndex ) );
+
+    return arc.GetP0() == m_points[aIndex];
+}
+
+
+bool SHAPE_LINE_CHAIN::IsArcEnd( size_t aIndex ) const
+{
+    size_t prevIndex = aIndex - 1;
+
+    if( aIndex == 0 )
+        prevIndex = m_points.size() - 1;
+    else if( aIndex > m_points.size() -1 )
+        return false; // invalid index requested
+
+    if( !IsArcSegment( prevIndex ) )
+        return false;
+
+    if( IsSharedPt( aIndex ) )
+        return true;
+
+    const SHAPE_ARC& arc = Arc( ArcIndex( aIndex ) );
+
+    return arc.GetP1() == m_points[aIndex];
+}
