@@ -35,7 +35,7 @@
 #include <pcb_plot_params.h>
 #include <title_block.h>
 #include <tools/pcb_selection.h>
-#include <mutex>
+#include <shared_mutex>
 #include <list>
 
 class BOARD_DESIGN_SETTINGS;
@@ -1133,7 +1133,10 @@ public:
      * the clearances from board design settings as well as embedded clearances in footprints,
      * pads and zones.  Includes electrical, physical, hole and edge clearances.
     */
-    int GetMaxClearanceValue() const;
+    int GetMaxClearanceValue() const
+    {
+        return m_maxClearanceValue;
+    };
 
     /**
      * Map all nets in the given board to nets with the same name (if any) in the destination
@@ -1227,7 +1230,7 @@ public:
     };
 
     // ------------ Run-time caches -------------
-    std::mutex                                            m_CachesMutex;
+    mutable std::shared_mutex                             m_CachesMutex;
     std::unordered_map<PTR_PTR_CACHE_KEY, bool>           m_IntersectsCourtyardCache;
     std::unordered_map<PTR_PTR_CACHE_KEY, bool>           m_IntersectsFCourtyardCache;
     std::unordered_map<PTR_PTR_CACHE_KEY, bool>           m_IntersectsBCourtyardCache;
@@ -1260,6 +1263,9 @@ private:
             ( l->*aFunc )( std::forward<Args>( args )... );
     }
 
+
+    void UpdateMaxClearanceCache();
+
     friend class PCB_EDIT_FRAME;
 
 
@@ -1314,6 +1320,9 @@ private:
      */
     bool                         m_legacyTeardrops = false;
 
+    bool                         m_deleting;        // inside destructor
+    int                          m_maxClearanceValue;  // cached value
+
     NETINFO_LIST                 m_NetInfo;         // net info list (name, design constraints...
 
     std::vector<BOARD_LISTENER*> m_listeners;
