@@ -323,6 +323,9 @@ bool STEP_PCB_MODEL::AddCopperPolygonShapes( const SHAPE_POLY_SET* aPolyShapes,
 {
     bool success = true;
 
+    if( aPolyShapes->IsEmpty() )
+        return true;
+
     double z_pos = aOnTop ? m_boardThickness : -m_copperThickness;
 
     if( !MakeShapes( aTrack ? m_board_copper_tracks : m_board_copper_zones, *aPolyShapes,
@@ -683,8 +686,11 @@ bool STEP_PCB_MODEL::MakeShapes( std::vector<TopoDS_Shape>& aShapes, const SHAPE
         {
             try
             {
-                auto addSegment = [&]( const VECTOR2D& aPt0, const VECTOR2D& aPt1 ) -> bool
+                auto addSegment = [&]( const VECTOR2I& aPt0, const VECTOR2I& aPt1 ) -> bool
                 {
+                    if( aPt0 == aPt1 )
+                        return false;
+
                     gp_Pnt start = toPoint( aPt0 );
                     gp_Pnt end = toPoint( aPt1 );
 
@@ -699,7 +705,9 @@ bool STEP_PCB_MODEL::MakeShapes( std::vector<TopoDS_Shape>& aShapes, const SHAPE
 
                     if( !mkEdge.IsDone() || mkEdge.Edge().IsNull() )
                     {
-                        ReportMessage( wxT( "failed to make edge, skipping\n" ) );
+                        ReportMessage( wxString::Format( wxT( "failed to make segment edge at (%d "
+                                                              "%d) -> (%d %d), skipping\n" ),
+                                                         aPt0.x, aPt0.y, aPt1.x, aPt1.y ) );
                     }
                     else
                     {
@@ -707,7 +715,9 @@ bool STEP_PCB_MODEL::MakeShapes( std::vector<TopoDS_Shape>& aShapes, const SHAPE
 
                         if( aMkWire.Error() != BRepLib_WireDone )
                         {
-                            ReportMessage( wxT( "failed to add edge to wire\n" ) );
+                            ReportMessage( wxString::Format( wxT( "failed to add segment edge "
+                                                                  "at (%d %d) -> (%d %d)\n" ),
+                                                             aPt0.x, aPt0.y, aPt1.x, aPt1.y ) );
                             return false;
                         }
                     }
@@ -715,7 +725,7 @@ bool STEP_PCB_MODEL::MakeShapes( std::vector<TopoDS_Shape>& aShapes, const SHAPE
                     return true;
                 };
 
-                auto addArc = [&]( const SHAPE_ARC& aArc ) -> bool
+                auto addArc = [&]( const VECTOR2I& aPt0, const SHAPE_ARC& aArc ) -> bool
                 {
                     // Do not export too short segments: they create broken shape because OCC thinks
                     Handle( Geom_Curve ) curve;
@@ -730,7 +740,7 @@ bool STEP_PCB_MODEL::MakeShapes( std::vector<TopoDS_Shape>& aShapes, const SHAPE
                     }
                     else
                     {
-                        curve = GC_MakeArcOfCircle( toPoint( aArc.GetP0() ),
+                        curve = GC_MakeArcOfCircle( toPoint( aPt0 ),
                                                     toPoint( aArc.GetArcMid() ),
                                                     toPoint( aArc.GetP1() ) )
                                         .Value();
@@ -743,7 +753,11 @@ bool STEP_PCB_MODEL::MakeShapes( std::vector<TopoDS_Shape>& aShapes, const SHAPE
 
                     if( !aMkWire.IsDone() )
                     {
-                        ReportMessage( wxT( "failed to add curve\n" ) );
+                        ReportMessage( wxString::Format(
+                                wxT( "failed to add arc curve from (%d %d), arc p0 "
+                                     "(%d %d), mid (%d %d), p1 (%d %d)\n" ),
+                                aPt0.x, aPt0.y, aArc.GetP0().x, aArc.GetP0().y, aArc.GetArcMid().x,
+                                aArc.GetArcMid().y, aArc.GetP1().x, aArc.GetP1().y ) );
                         return false;
                     }
 
@@ -766,7 +780,7 @@ bool STEP_PCB_MODEL::MakeShapes( std::vector<TopoDS_Shape>& aShapes, const SHAPE
                             int nextShape = aChain.NextShape( i );
 
                             // If nextShape points to the end, then we have a circle.
-                            if( nextShape != aChain.PointCount() - 1 )
+                            if( nextShape != -1 )
                                 i = nextShape;
                         }
                     }
@@ -786,10 +800,10 @@ bool STEP_PCB_MODEL::MakeShapes( std::vector<TopoDS_Shape>& aShapes, const SHAPE
                             lastPt = firstPt;
                         }
 
-                        if( lastPt != currentArc.GetP0() )
-                            addSegment( lastPt, currentArc.GetP0() );
+                        if( addSegment( lastPt, currentArc.GetP0() ) )
+                            lastPt = currentArc.GetP0();
 
-                        if( addArc( currentArc ) )
+                        if( addArc( lastPt, currentArc ) )
                             lastPt = currentArc.GetP1();
                     }
                     else if( !isArc )
@@ -802,10 +816,10 @@ bool STEP_PCB_MODEL::MakeShapes( std::vector<TopoDS_Shape>& aShapes, const SHAPE
                             lastPt = firstPt;
                         }
 
-                        if( lastPt != seg.A )
-                            addSegment( lastPt, seg.A );
+                        if( addSegment( lastPt, seg.A ) )
+                            lastPt = seg.A;
 
-                        if( addSegment( seg.A, seg.B ) )
+                        if( addSegment( lastPt, seg.B ) )
                             lastPt = seg.B;
                     }
 
@@ -837,18 +851,32 @@ bool STEP_PCB_MODEL::MakeShapes( std::vector<TopoDS_Shape>& aShapes, const SHAPE
                 if( !makeWireFromChain( mkWire, contour ) )
                     continue;
 
-                wxASSERT( mkWire.IsDone() );
+                if( !mkWire.IsDone() )
+                {
+                    ReportMessage( wxString::Format(
+                            _( "Wire not done (contour %d, points %d): OCC error %d\n" ),
+                            static_cast<int>( contId ), static_cast<int>( contour.PointCount() ),
+                            static_cast<int>( mkWire.Error() ) ) );
+                }
 
                 if( contId == 0 ) // Outline
-                    mkFace = BRepBuilderAPI_MakeFace( mkWire.Wire() );
+                {
+                    if( mkWire.IsDone() )
+                        mkFace = BRepBuilderAPI_MakeFace( mkWire.Wire() );
+                    else
+                        continue;
+                }
                 else // Hole
-                    mkFace.Add( mkWire );
+                {
+                    if( mkWire.IsDone() )
+                        mkFace.Add( mkWire );
+                }
             }
             catch( const Standard_Failure& e )
             {
                 ReportMessage(
                         wxString::Format( wxT( "MakeShapes (contour %d): OCC exception: %s\n" ),
-                                          contId, e.GetMessageString() ) );
+                                          static_cast<int>( contId ), e.GetMessageString() ) );
                 return false;
             }
         }
@@ -889,21 +917,44 @@ bool STEP_PCB_MODEL::CreatePCB( SHAPE_POLY_SET& aOutline, VECTOR2D aOrigin )
 
 
     // Support for more than one main outline (more than one board)
-    for( int cnt = 0; cnt < aOutline.OutlineCount(); cnt++ )
+    ReportMessage( wxString::Format( wxT( "Build board outlines (%d outlines) with %d points.\n" ),
+                                     aOutline.OutlineCount(), aOutline.FullPointCount() ) );
+#if 0
+    // This code should work, and it is working most of time
+    // However there are issues if the main outline is a circle with holes:
+    // holes from vias and pads are not working
+    // see bug https://gitlab.com/kicad/code/kicad/-/issues/17446
+    // (Holes are missing from STEP export with circular PCB outline)
+    // Hard to say if the bug is in our code or in OCC 7.7
+    if( !MakeShapes( m_board_outlines, aOutline, m_boardThickness, 0.0, aOrigin ) )
     {
-        const SHAPE_LINE_CHAIN& outline = aOutline.COutline( cnt );
-
-        ReportMessage( wxString::Format( wxT( "Build board main outline %d with %d points.\n" ),
-                                         cnt + 1, outline.PointCount() ) );
-
-        if( !MakeShapes( m_board_outlines, aOutline, m_boardThickness, 0.0, aOrigin ) )
+        // Error
+        ReportMessage( wxString::Format(
+                wxT( "OCC error creating main outline.\n" ) ) );
+    }
+#else
+    // Workaround for bug #17446 Holes are missing from STEP export with circular PCB outline
+    for( const SHAPE_POLY_SET::POLYGON& polygon : aOutline.CPolygons() )
+    {
+        for( size_t contId = 0; contId < polygon.size(); contId++ )
         {
-            // Error
-            ReportMessage( wxString::Format(
-                    wxT( "OCC error adding main outline polygon %d with %d points.\n" ), cnt + 1,
-                    outline.PointCount() ) );
+            const SHAPE_LINE_CHAIN& contour = polygon[contId];
+            SHAPE_POLY_SET polyset;
+            polyset.Append( contour );
+
+            if( contId == 0 ) // main Outline
+            {
+                if( !MakeShapes( m_board_outlines, polyset, m_boardThickness, 0.0, aOrigin ) )
+                    ReportMessage( wxT( "OCC error creating main outline.\n" ) );
+            }
+            else // Hole inside the main outline
+            {
+                if( !MakeShapes( m_boardCutouts, polyset, m_boardThickness, 0.0, aOrigin ) )
+                    ReportMessage( wxT( "OCC error creating hole in main outline.\n" ) );
+            }
         }
     }
+#endif
 
     Bnd_Box brdBndBox;
 
