@@ -228,7 +228,11 @@ public:
     }
 
     const LIB_ID& GetFPID() const { return m_fpid; }
-    void SetFPID( const LIB_ID& aFPID ) { m_fpid = aFPID; }
+    void          SetFPID( const LIB_ID& aFPID )
+    {
+        m_fpid = aFPID;
+        Footprint().SetText( aFPID.Format() );
+    }
 
     wxString GetFPIDAsString() const { return m_fpid.Format(); }
     void SetFPIDAsString( const wxString& aFPID ) { m_fpid.Parse( aFPID ); }
@@ -778,6 +782,12 @@ public:
      */
     unsigned GetUniquePadCount( INCLUDE_NPTH_T aIncludeNPTH = INCLUDE_NPTH_T(INCLUDE_NPTH) ) const;
 
+    /**
+     * Return the names of the unique, non-blank pads.
+     */
+    std::set<wxString>
+    GetUniquePadNumbers( INCLUDE_NPTH_T aIncludeNPTH = INCLUDE_NPTH_T(INCLUDE_NPTH) ) const;
+
     /**
      * Return the next available pad number in the footprint.
      *
@@ -1015,6 +1025,7 @@ private:
     SHAPE_POLY_SET  m_courtyard_cache_front;  // Note that a footprint can have both front and back
     SHAPE_POLY_SET  m_courtyard_cache_back;   // courtyards populated.
     mutable int     m_courtyard_cache_timestamp;
+    mutable std::mutex      m_courtyard_cache_mutex;
 };
 
 #endif     // FOOTPRINT_H
