@@ -194,10 +194,7 @@ void FP_CACHE::Load()
                 wxString fpName = fn.GetName();
 
                 if( !footprint )
-                {
-                    THROW_IO_ERROR( wxString::Format( _( "Unable to read file '%s'" ),
-                                                      fn.GetFullPath() ) );
-                }
+                    THROW_IO_ERROR( wxEmptyString );   // caught locally, just below...
 
                 footprint->SetFPID( LIB_ID( wxEmptyString, fpName ) );
                 m_footprints.insert( fpName, new FP_CACHE_ITEM( footprint, fn ) );
@@ -207,6 +204,8 @@ void FP_CACHE::Load()
                 if( !cacheError.IsEmpty() )
                     cacheError += wxT( "\n\n" );
 
+                cacheError += wxString::Format( _( "Unable to read file '%s'" ) + '\n',
+                                                fn.GetFullPath() );
                 cacheError += ioe.What();
             }
         } while( dir.GetNext( &fullName ) );
@@ -2666,10 +2665,11 @@ void PCB_IO_KICAD_SEXPR::FootprintSave( const wxString& aLibraryPath, const FOOT
     wxString footprintName = aFootprint->GetFPID().GetLibItemName();
 
     FP_CACHE_FOOTPRINT_MAP& footprints = m_cache->GetFootprints();
+    wxString fpName = aFootprint->GetFPID().GetLibItemName().wx_str();
+    ReplaceIllegalFileNameChars( fpName, '_' );
 
     // Quietly overwrite footprint and delete footprint file from path for any by same name.
-    wxFileName fn( aLibraryPath, aFootprint->GetFPID().GetLibItemName(),
-                   FILEEXT::KiCadFootprintFileExtension );
+    wxFileName fn( aLibraryPath, fpName, FILEEXT::KiCadFootprintFileExtension );
 
     // Write through symlinks, don't replace them
     WX_FILENAME::ResolvePossibleSymlinks( fn );
