@@ -2,7 +2,7 @@
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
  * Copyright (C) 2013-2019 CERN
- * Copyright (C) 2021-2023 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 2021-2024 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * @author Tomasz Wlostowski <tomasz.wlostowski@cern.ch>
  * @author Maciej Suminski <maciej.suminski@cern.ch>
@@ -1142,10 +1142,10 @@ void PCB_PAINTER::draw( const PAD* aPad, int aLayer )
             padNumber = UnescapeString( aPad->GetNumber() );
 
             if( dynamic_cast<CVPCB_SETTINGS*>( viewer_settings() ) )
-                netname = aPad->GetUnescapedShortNetname();
+                netname = aPad->GetPinFunction();
         }
 
-        if( displayOpts )
+        if( displayOpts && !dynamic_cast<CVPCB_SETTINGS*>( viewer_settings() ) )
         {
             if( displayOpts->m_NetNames == 1 || displayOpts->m_NetNames == 3 )
                 netname = aPad->GetUnescapedShortNetname();
@@ -1694,8 +1694,12 @@ void PCB_PAINTER::draw( const PCB_SHAPE* aShape, int aLayer )
     int        thickness = getLineThickness( aShape->GetWidth() );
     LINE_STYLE lineStyle = aShape->GetStroke().GetLineStyle();
 
-    if( IsNetnameLayer( aLayer ) && m_frameType == FRAME_T::FRAME_PCB_EDITOR )
+    if( IsNetnameLayer( aLayer ) )
     {
+        // Net names are shown only in board editor:
+        if( m_frameType != FRAME_T::FRAME_PCB_EDITOR )
+            return;
+
         if( !pcbconfig() || pcbconfig()->m_Display.m_NetNames < 2 )
             return;
 
