@@ -1149,13 +1149,13 @@ void ZONE_FILLER::buildCopperItemClearances( const ZONE* aZone, PCB_LAYER_ID aLa
                         else if( aItem->IsOnLayer( Edge_Cuts ) )
                         {
                             gap = std::max( gap, evalRulesForItems( EDGE_CLEARANCE_CONSTRAINT,
-                                                                    aZone, aItem, Edge_Cuts ) );
+                                                                    aZone, aItem, aLayer ) );
                             ignoreLineWidths = true;
                         }
                         else if( aItem->IsOnLayer( Margin ) )
                         {
                             gap = std::max( gap, evalRulesForItems( EDGE_CLEARANCE_CONSTRAINT,
-                                                                    aZone, aItem, Margin ) );
+                                                                    aZone, aItem, aLayer ) );
                         }
 
                         if( gap > 0 )
@@ -1177,7 +1177,7 @@ void ZONE_FILLER::buildCopperItemClearances( const ZONE* aZone, PCB_LAYER_ID aLa
         {
             for( PAD* pad : footprint->Pads() )
             {
-                if( pad->GetNetCode() == aZone->GetNetCode() )
+                if( pad->GetNetCode() == aZone->GetNetCode() && aZone->GetNetCode() != 0 )
                 {
                     if( pad->IsOnLayer( aLayer ) )
                         allowedNetTiePads.insert( pad );
